@@ -1,4 +1,4 @@
-# Copyright 2022 The Plenoptix Team. All rights reserved.
+# Copyright 2022 The Nerfstudio Team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -89,8 +89,6 @@ class RaySamples(TensorDataclass):
     """Frustums along ray."""
     camera_indices: Optional[TensorType["bs":..., 1]] = None
     """Camera index."""
-    valid_mask: Optional[TensorType["bs":..., 1]] = None
-    """Rays that are valid."""
     deltas: Optional[TensorType["bs":..., 1]] = None
     """"width" of each sample."""
     spacing_starts: Optional[TensorType["bs":..., "num_samples", 1]] = None
@@ -115,42 +113,16 @@ class RaySamples(TensorDataclass):
         delta_density = self.deltas * densities
         alphas = 1 - torch.exp(-delta_density)
 
-        # TODO: put both versions of the transmittance calculation somewhere
-        # mip-nerf version of transmittance calculation:
         transmittance = torch.cumsum(delta_density[..., :-1, :], dim=-2)
         transmittance = torch.cat(
             [torch.zeros((*transmittance.shape[:1], 1, 1), device=densities.device), transmittance], dim=-2
         )
         transmittance = torch.exp(-transmittance)  # [..., "num_samples"]
 
-        # most nerf codebases do the following:
-        # transmittance = torch.cat(
-        #     [torch.ones((*alphas.shape[:1], 1)).to(densities.device), 1.0 - alphas + 1e-10], dim=-1
-        # )
-        # transmittance = torch.cumprod(transmittance, dim=-1)[..., :-1]  # [..., "num_samples"]
-
         weights = alphas * transmittance  # [..., "num_samples"]
 
         return weights
 
-    def set_valid_mask(self, valid_mask: TensorType[..., "num_samples"]) -> None:
-        """Sets valid mask
-
-        Args:
-            valid_mask: the mask to use
-        """
-        self.valid_mask = valid_mask
-
-    def apply_masks(self) -> "RaySamples":
-        """Use valid_mask to mask samples.
-
-        Returns:
-            New set of masked samples.
-        """
-        if self.valid_mask is not None:
-            return self[self.valid_mask[..., 0]]
-        return self
-
 
 @dataclass
 class RayBundle(TensorDataclass):
@@ -169,8 +141,6 @@ class RayBundle(TensorDataclass):
     """Distance along ray to start sampling"""
     fars: Optional[TensorType[..., 1]] = None
     """Rays Distance along ray to stop sampling"""
-    valid_mask: Optional[TensorType[..., 1, bool]] = None
-    """Rays that are valid"""
     metadata: Optional[Dict[str, TensorType["num_rays", "latent_dims"]]] = None
     """Additional metadata or data needed for interpolation, will mimic shape of rays"""
 
@@ -216,9 +186,9 @@ class RayBundle(TensorDataclass):
         self,
         bin_starts: TensorType["bs":..., "num_samples", 1],
         bin_ends: TensorType["bs":..., "num_samples", 1],
-        spacing_starts: Optional[TensorType["bs":..., "num_samples", 1]],
-        spacing_ends: Optional[TensorType["bs":..., "num_samples", 1]],
-        spacing_to_euclidean_fn: Optional[Callable],
+        spacing_starts: Optional[TensorType["bs":..., "num_samples", 1]] = None,
+        spacing_ends: Optional[TensorType["bs":..., "num_samples", 1]] = None,
+        spacing_to_euclidean_fn: Optional[Callable] = None,
     ) -> RaySamples:
         """Produces samples for each ray by projection points along the ray direction. Currently samples uniformly.
 
@@ -231,8 +201,6 @@ class RayBundle(TensorDataclass):
         """
         device = self.origins.device
 
-        valid_mask = torch.ones((bin_starts.shape), dtype=torch.bool, device=device)
-
         dists = bin_ends - bin_starts  # [..., num_samples, 1]
         deltas = dists * torch.norm(self.directions[:, :], dim=-1)[..., None, None]
 
@@ -254,7 +222,6 @@ class RayBundle(TensorDataclass):
         ray_samples = RaySamples(
             frustums=frustums,
             camera_indices=camera_indices,  # [..., 1, 1]
-            valid_mask=valid_mask,  # [..., num_samples, 1]
             deltas=deltas,  # [..., num_samples, 1]
             spacing_starts=spacing_starts,  # [..., num_samples, 1]
             spacing_ends=spacing_ends,  # [..., num_samples, 1]
