@@ -1,4 +1,4 @@
-# Copyright 2022 The Plenoptix Team. All rights reserved.
+# Copyright 2022 The Nerfstudio Team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -30,10 +30,11 @@ from rich.console import Console
 
 from nerfstudio.cameras.cameras import Cameras
 from nerfstudio.cameras.rays import RayBundle
-from nerfstudio.configs import base as cfg
-from nerfstudio.datamanagers.datasets import InputDataset
-from nerfstudio.models.base import Model
-from nerfstudio.utils import profiler, visualization, writer
+from nerfstudio.configs import base_config as cfg
+from nerfstudio.data.utils.datasets import InputDataset
+from nerfstudio.models.base_model import Model
+from nerfstudio.utils import colormaps, profiler, writer
+from nerfstudio.utils.decorators import check_main_thread, decorate_all
 from nerfstudio.utils.io import load_from_json, write_to_json
 from nerfstudio.utils.misc import get_dict_to_torch
 from nerfstudio.utils.writer import GLOBAL_BUFFER, EventName, TimeWriter
@@ -44,6 +45,7 @@ from nerfstudio.viewer.server.visualizer import Viewer
 console = Console(width=120)
 
 
+@check_main_thread
 def setup_viewer(config: cfg.ViewerConfig, log_filename: Path):
     """Sets up the viewer if enabled
 
@@ -193,6 +195,7 @@ class CheckThread(threading.Thread):
                     return
 
 
+@decorate_all([check_main_thread])
 class ViewerState:
     """Class to hold state for viewer variables
 
@@ -209,8 +212,8 @@ class ViewerState:
             # start the viewer bridge server
             websocket_port = self.config.websocket_port
             self.log_filename.parent.mkdir(exist_ok=True)
-            run_viewer_bridge_server_as_subprocess(
-                self.config.zmq_port, websocket_port, log_filename=str(self.log_filename)
+            zmq_port = run_viewer_bridge_server_as_subprocess(
+                websocket_port, zmq_port=self.config.zmq_port, log_filename=str(self.log_filename)
             )
             # TODO(ethan): move this into the writer such that it's at the bottom
             # of the logging stack and easy to see and click
@@ -218,8 +221,8 @@ class ViewerState:
             console.line()
             json_filename = os.path.join(os.path.dirname(__file__), "../app/package.json")
             version = load_from_json(Path(json_filename))["version"]
-            self.viewer_url = f"https://viewer.nerfactory.com/{version}/?websocket_url=localhost:{websocket_port}"
-            viewer_url_local = f"http://localhost:4000/?websocket_url=localhost:{websocket_port}"
+            self.viewer_url = f"https://viewer.nerf.studio/versions/{version}/?websocket_port={websocket_port}"
+            viewer_url_local = f"http://localhost:4000/?websocket_port={websocket_port}"
             pub_open_viewer_instructions_string = f"[Public] Open the viewer at {self.viewer_url}"
             dev_open_viewer_instructions_string = f"[Local] Open the viewer at {viewer_url_local}"
             console.rule(characters="=")
@@ -227,7 +230,10 @@ class ViewerState:
             console.print(dev_open_viewer_instructions_string)
             console.rule(characters="=")
             console.line()
-        self.vis = Viewer(zmq_port=self.config.zmq_port)
+            self.vis = Viewer(zmq_port=zmq_port)
+        else:
+            assert self.config.zmq_port is not None
+            self.vis = Viewer(zmq_port=self.config.zmq_port)
 
         # viewer specific variables
         self.prev_camera_matrix = None
@@ -258,7 +264,7 @@ class ViewerState:
         self.vis["renderingState/config_base_dir"].write(str(self.log_filename.parents[0]))
 
         # clear the current scene
-        self.vis["sceneState/sceneBounds"].delete()
+        self.vis["sceneState/sceneBox"].delete()
         self.vis["sceneState/cameras"].delete()
 
         # draw the training cameras and images
@@ -266,12 +272,12 @@ class ViewerState:
         for idx in image_indices:
             image = dataset[idx]["image"]
             bgr = image[..., [2, 1, 0]]
-            camera_json = dataset.dataset_inputs.cameras.to_json(camera_idx=idx, image=bgr, max_size=100)
+            camera_json = dataset.dataparser_outputs.cameras.to_json(camera_idx=idx, image=bgr, max_size=100)
             self.vis[f"sceneState/cameras/{idx:06d}"].write(camera_json)
 
-        # draw the scene bounds (i.e., the bounding box)
-        json_ = dataset.dataset_inputs.scene_bounds.to_json()
-        self.vis["sceneState/sceneBounds"].write(json_)
+        # draw the scene box (i.e., the bounding box)
+        json_ = dataset.dataparser_outputs.scene_box.to_json()
+        self.vis["sceneState/sceneBox"].write(json_)
 
         # set the initial state whether to train or not
         self.vis["renderingState/isTraining"].write(start_train)
@@ -283,6 +289,19 @@ class ViewerState:
         # K = camera.get_intrinsics_matrix()
         # set_persp_intrinsics_matrix(self.vis, K.double().numpy())
 
+    def _check_camera_path_payload(self, trainer, step: int):
+        """Check to see if the camera path export button was pressed."""
+        # check if we should interrupt from a button press?
+        camera_path_payload = self.vis["camera_path_payload"].read()
+        if camera_path_payload:
+            # save a model checkpoint
+            trainer.save_checkpoint(step)
+            # write to json file
+            camera_path_filename = camera_path_payload["camera_path_filename"]
+            camera_path = camera_path_payload["camera_path"]
+            write_to_json(Path(camera_path_filename), camera_path)
+            self.vis["camera_path_payload"].delete()
+
     def update_scene(self, trainer, step: int, graph: Model, num_rays_per_batch: int) -> None:
         """updates the scene based on the graph weights
 
@@ -294,16 +313,7 @@ class ViewerState:
         is_training = self.vis["renderingState/isTraining"].read()
         self.step = step
 
-        # check if we should interrupt from a button press?
-        camera_path_payload = self.vis["camera_path_payload"].read()
-        if camera_path_payload:
-            # save a model checkpoint
-            trainer.save_checkpoint(step)
-            # write to json file
-            camera_path_filename = camera_path_payload["camera_path_filename"]
-            camera_path = camera_path_payload["camera_path"]
-            write_to_json(Path(camera_path_filename), camera_path)
-            self.vis["camera_path_payload"].delete()
+        self._check_camera_path_payload(trainer, step)
 
         camera_object = self._get_camera_object()
         if camera_object is None:
@@ -347,6 +357,7 @@ class ViewerState:
                     self._render_image_in_viewer(camera_object, graph, is_training)
                     camera_object = self._get_camera_object()
                 is_training = self.vis["renderingState/isTraining"].read()
+                self._check_camera_path_payload(trainer, step)
                 run_loop = not is_training
                 local_step += 1
 
@@ -401,15 +412,13 @@ class ViewerState:
                 if OutputTypes.ACCUMULATION in self.output_list
                 else OutputTypes.ACCUMULATION_FINE
             )
-            return visualization.apply_depth_colormap(
-                outputs[reformatted_output], accumulation=outputs[accumulation_str]
-            )
+            return colormaps.apply_depth_colormap(outputs[reformatted_output], accumulation=outputs[accumulation_str])
 
         # rendering accumulation outputs
         if self.prev_colormap_type == ColormapTypes.TURBO or (
             self.prev_colormap_type == ColormapTypes.DEFAULT and outputs[reformatted_output].dtype == torch.float
         ):
-            return visualization.apply_colormap(outputs[reformatted_output])
+            return colormaps.apply_colormap(outputs[reformatted_output])
 
         # rendering semantic outputs
         if self.prev_colormap_type == ColormapTypes.SEMANTIC or (
@@ -424,7 +433,7 @@ class ViewerState:
         if self.prev_colormap_type == ColormapTypes.BOOLEAN or (
             self.prev_colormap_type == ColormapTypes.DEFAULT and outputs[reformatted_output].dtype == torch.bool
         ):
-            return visualization.apply_boolean_colormap(outputs[reformatted_output])
+            return colormaps.apply_boolean_colormap(outputs[reformatted_output])
 
         raise NotImplementedError
 
@@ -533,8 +542,12 @@ class ViewerState:
         image_height = (num_vis_rays / aspect_ratio) ** 0.5
         image_height = int(round(image_height, -1))
         image_height = min(self.max_resolution, image_height)
+        image_width = int(image_height * aspect_ratio)
+        if image_width > self.max_resolution:
+            image_width = self.max_resolution
+            image_height = int(image_width / aspect_ratio)
 
-        return image_height, int(image_height * aspect_ratio)
+        return image_height, image_width
 
     def _process_invalid_output(self, output_type: str) -> str:
         """Check to see whether we are in the corner case of RGB; if still invalid, throw error
@@ -626,6 +639,7 @@ class ViewerState:
         check_thread = CheckThread(state=self)
         render_thread = RenderThread(state=self, graph=graph, camera_ray_bundle=camera_ray_bundle)
 
+        oom = False
         with TimeWriter(None, None, write=False) as vis_t:
             check_thread.start()
             render_thread.start()
@@ -635,13 +649,15 @@ class ViewerState:
             except IOChangeException:
                 pass
             except RuntimeError as e:
-                del camera_ray_bundle
-                torch.cuda.empty_cache()
-                time.sleep(0.5)  # sleep to allow buffer to reset
+                oom = True
                 self.vis["renderingState/log_errors"].write(
                     "Error: GPU out of memory. Reduce resolution to prevent viewer from crashing."
                 )
                 print(f"Error: {e}")
+        if oom:
+            del camera_ray_bundle
+            torch.cuda.empty_cache()
+            time.sleep(0.5)  # sleep to allow buffer to reset
 
         graph.train()
         outputs = render_thread.vis_outputs
